@@ -115,7 +115,7 @@ class AthenaClient:
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
                     response_as_df = pd.DataFrame.from_dict(response[RESULT]).style.set_caption(
-                        f'Tables in schema: {schema_name}').hide_index().set_table_styles(TABLE_STYLES)
+                        "Tables").hide_index().set_table_styles(TABLE_STYLES)
                     return display(response_as_df)
                 else:
                     return response[RESULT]
@@ -141,7 +141,7 @@ class AthenaClient:
             response = r.json()
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
-                    table_header = f'Top {limit} records of table {schema_name}.{table_name}' if limit else f'Top 100 records of table {schema_name}.{table_name}'
+                    table_header = f'Top {limit} records of table {schema_name}.{table_name}' if limit else f'Top 100 records of table <i>{schema_name}.{table_name}</i>'
                     response_as_df = pd.DataFrame.from_dict(response[RESULT]).style.set_caption(
                         table_header).hide_index().set_table_styles(TABLE_STYLES)
                     return display(response_as_df)
@@ -170,10 +170,16 @@ class AthenaClient:
             if response[STATUS] == SUCCESS:
                 if result_as_df and isinstance(response[RESULT], (dict, list)):
                     queries = query_string.split(';')
-                    results = [pd.DataFrame.from_dict(item).style.set_caption(
-                        f"""Query results for \"{queries[i]};\"""").hide_index().set_table_styles(TABLE_STYLES) for i, item in
-                               enumerate(response[RESULT])]
-                    display(*results)
+                    if len(queries) > 0:
+                        results = [pd.DataFrame.from_dict(item).style.set_caption(
+                            f"""Query results for <i>\"{queries[i]};\"</i>""").hide_index().set_table_styles(TABLE_STYLES) for i, item in
+                                   enumerate(response[RESULT])]
+                        return display(*results)
+                    else:
+                        result = pd.DataFrame.from_dict(response[RESULT]).style.set_caption(
+                            f"""Query results for <i>\"{queries[0]};\"</i>""").hide_index().set_table_styles(
+                            TABLE_STYLES)
+                        return display(result)
                 else:
                     return response[RESULT]
             else:
